aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--plugins/Makefile.nmake2
-rw-r--r--plugins/asn1/packet-asn1.c86
-rw-r--r--plugins/docsis/packet-bpkmattr.c2
-rw-r--r--plugins/docsis/packet-bpkmreq.c2
-rw-r--r--plugins/docsis/packet-bpkmrsp.c2
-rw-r--r--plugins/docsis/packet-dccack.c2
-rw-r--r--plugins/docsis/packet-dccreq.c2
-rw-r--r--plugins/docsis/packet-dccrsp.c2
-rw-r--r--plugins/docsis/packet-dcd.c2
-rw-r--r--plugins/docsis/packet-docsis.c4
-rw-r--r--plugins/docsis/packet-dsaack.c2
-rw-r--r--plugins/docsis/packet-dsareq.c2
-rw-r--r--plugins/docsis/packet-dsarsp.c2
-rw-r--r--plugins/docsis/packet-dscack.c2
-rw-r--r--plugins/docsis/packet-dscreq.c2
-rw-r--r--plugins/docsis/packet-dscrsp.c2
-rw-r--r--plugins/docsis/packet-dsdreq.c2
-rw-r--r--plugins/docsis/packet-dsdrsp.c2
-rw-r--r--plugins/docsis/packet-intrngreq.c2
-rw-r--r--plugins/docsis/packet-macmgmt.c2
-rw-r--r--plugins/docsis/packet-map.c2
-rw-r--r--plugins/docsis/packet-regack.c2
-rw-r--r--plugins/docsis/packet-regreq.c2
-rw-r--r--plugins/docsis/packet-regrsp.c2
-rw-r--r--plugins/docsis/packet-rngreq.c2
-rw-r--r--plugins/docsis/packet-rngrsp.c2
-rw-r--r--plugins/docsis/packet-tlv.c2
-rw-r--r--plugins/docsis/packet-type29ucd.c2
-rw-r--r--plugins/docsis/packet-uccreq.c2
-rw-r--r--plugins/docsis/packet-uccrsp.c2
-rw-r--r--plugins/docsis/packet-ucd.c2
-rw-r--r--plugins/docsis/packet-vendor.c2
-rw-r--r--plugins/giop/packet-coseventcomm.c2
-rw-r--r--plugins/h223/packet-h223.c4
-rw-r--r--plugins/h223/packet-srp.c4
-rw-r--r--plugins/irda/packet-irda.c2
-rw-r--r--plugins/lua/elua.c2
-rw-r--r--plugins/lua/elua.h2
-rw-r--r--plugins/lua/elua_dumper.c2
-rw-r--r--plugins/lua/elua_field.c2
-rw-r--r--plugins/lua/elua_gui.c2
-rw-r--r--plugins/lua/elua_pinfo.c2
-rw-r--r--plugins/lua/elua_plugin.c2
-rw-r--r--plugins/lua/elua_proto.c2
-rw-r--r--plugins/lua/elua_tap.c4
-rw-r--r--plugins/lua/elua_tree.c2
-rw-r--r--plugins/lua/elua_tvb.c4
-rw-r--r--plugins/mate/mate_setup.c2
-rw-r--r--plugins/mate/packet-mate.c2
-rw-r--r--plugins/rlm/packet-rlm.c2
-rw-r--r--plugins/v5ua/packet-v5ua.c2
51 files changed, 98 insertions, 98 deletions
diff --git a/plugins/Makefile.nmake b/plugins/Makefile.nmake
index 7577fb372f..71785175fd 100644
--- a/plugins/Makefile.nmake
+++ b/plugins/Makefile.nmake
@@ -320,7 +320,7 @@ maintainer-clean: distclean
cd ..
################################################################################
-# copy all plugins to /plugins/$(VERSION), so Ethereal will load them, when
+# copy all plugins to /plugins/$(VERSION), so Wireshark will load them, when
# started from within the source tree.
################################################################################
diff --git a/plugins/docsis/packet-bpkmattr.c b/plugins/docsis/packet-bpkmattr.c
index 4652d62dd5..77a5f92a06 100644
--- a/plugins/docsis/packet-bpkmattr.c
+++ b/plugins/docsis/packet-bpkmattr.c
@@ -384,7 +384,7 @@ dissect_bpkmattr (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-bpkmreq.c b/plugins/docsis/packet-bpkmreq.c
index e87c2f62f8..f8364b343e 100644
--- a/plugins/docsis/packet-bpkmreq.c
+++ b/plugins/docsis/packet-bpkmreq.c
@@ -114,7 +114,7 @@ dissect_bpkmreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-bpkmrsp.c b/plugins/docsis/packet-bpkmrsp.c
index ee2ad21aad..4ee0c0d676 100644
--- a/plugins/docsis/packet-bpkmrsp.c
+++ b/plugins/docsis/packet-bpkmrsp.c
@@ -115,7 +115,7 @@ dissect_bpkmrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dccack.c b/plugins/docsis/packet-dccack.c
index e55296cdea..edd5be4582 100644
--- a/plugins/docsis/packet-dccack.c
+++ b/plugins/docsis/packet-dccack.c
@@ -114,7 +114,7 @@ dissect_dccack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
} /* if (tree) */
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dccreq.c b/plugins/docsis/packet-dccreq.c
index 1f3c74d77e..3acf74bfd6 100644
--- a/plugins/docsis/packet-dccreq.c
+++ b/plugins/docsis/packet-dccreq.c
@@ -381,7 +381,7 @@ dissect_dccreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
} /* if (tree) */
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dccrsp.c b/plugins/docsis/packet-dccrsp.c
index d43891eecd..70ad4809a2 100644
--- a/plugins/docsis/packet-dccrsp.c
+++ b/plugins/docsis/packet-dccrsp.c
@@ -174,7 +174,7 @@ dissect_dccrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
} /* if (tree) */
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dcd.c b/plugins/docsis/packet-dcd.c
index 1bfa44e845..ebfd5b7fca 100644
--- a/plugins/docsis/packet-dcd.c
+++ b/plugins/docsis/packet-dcd.c
@@ -561,7 +561,7 @@ dissect_dcd (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
} /* if (tree) */
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-docsis.c b/plugins/docsis/packet-docsis.c
index 29c31109b5..7388fc60f6 100644
--- a/plugins/docsis/packet-docsis.c
+++ b/plugins/docsis/packet-docsis.c
@@ -41,7 +41,7 @@
* be specified for some interfaces on some platforms; for Ethernet
* interfaces, it allows DOCSIS to be specified. If an Ethernet capture
* is done with a link-layer type of DOCSIS, the file will have a link-
- * layer type of DLT_DOCSIS; Ethereal will treat the frames in that capture
+ * layer type of DLT_DOCSIS; Wireshark will treat the frames in that capture
* as DOCSIS frames.
*/
@@ -571,7 +571,7 @@ dissect_docsis (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dsaack.c b/plugins/docsis/packet-dsaack.c
index a0841dba3f..a79fd302df 100644
--- a/plugins/docsis/packet-dsaack.c
+++ b/plugins/docsis/packet-dsaack.c
@@ -92,7 +92,7 @@ dissect_dsaack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dsareq.c b/plugins/docsis/packet-dsareq.c
index ae74928360..84e7dce376 100644
--- a/plugins/docsis/packet-dsareq.c
+++ b/plugins/docsis/packet-dsareq.c
@@ -85,7 +85,7 @@ dissect_dsareq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dsarsp.c b/plugins/docsis/packet-dsarsp.c
index a8a963b3a9..65bdd69eab 100644
--- a/plugins/docsis/packet-dsarsp.c
+++ b/plugins/docsis/packet-dsarsp.c
@@ -95,7 +95,7 @@ dissect_dsarsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dscack.c b/plugins/docsis/packet-dscack.c
index eaa6e448f6..882c6b12ad 100644
--- a/plugins/docsis/packet-dscack.c
+++ b/plugins/docsis/packet-dscack.c
@@ -94,7 +94,7 @@ dissect_dscack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dscreq.c b/plugins/docsis/packet-dscreq.c
index 091104cfee..68fcdebec7 100644
--- a/plugins/docsis/packet-dscreq.c
+++ b/plugins/docsis/packet-dscreq.c
@@ -86,7 +86,7 @@ dissect_dscreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dscrsp.c b/plugins/docsis/packet-dscrsp.c
index 5f126cd139..b24627ff12 100644
--- a/plugins/docsis/packet-dscrsp.c
+++ b/plugins/docsis/packet-dscrsp.c
@@ -93,7 +93,7 @@ dissect_dscrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dsdreq.c b/plugins/docsis/packet-dsdreq.c
index 586fb56ffd..b24aa4e669 100644
--- a/plugins/docsis/packet-dsdreq.c
+++ b/plugins/docsis/packet-dsdreq.c
@@ -90,7 +90,7 @@ dissect_dsdreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-dsdrsp.c b/plugins/docsis/packet-dsdrsp.c
index 2185a44bd6..ce0875158c 100644
--- a/plugins/docsis/packet-dsdrsp.c
+++ b/plugins/docsis/packet-dsdrsp.c
@@ -89,7 +89,7 @@ dissect_dsdrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-intrngreq.c b/plugins/docsis/packet-intrngreq.c
index 94504ed2d4..cdd3d6e528 100644
--- a/plugins/docsis/packet-intrngreq.c
+++ b/plugins/docsis/packet-intrngreq.c
@@ -86,7 +86,7 @@ dissect_intrngreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-macmgmt.c b/plugins/docsis/packet-macmgmt.c
index fbf6c2cdea..67704181ce 100644
--- a/plugins/docsis/packet-macmgmt.c
+++ b/plugins/docsis/packet-macmgmt.c
@@ -189,7 +189,7 @@ dissect_macmgmt (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-map.c b/plugins/docsis/packet-map.c
index f65be587ad..49c1a50e74 100644
--- a/plugins/docsis/packet-map.c
+++ b/plugins/docsis/packet-map.c
@@ -173,7 +173,7 @@ dissect_map (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-regack.c b/plugins/docsis/packet-regack.c
index 1ef5d1e26b..7a2a3b86b7 100644
--- a/plugins/docsis/packet-regack.c
+++ b/plugins/docsis/packet-regack.c
@@ -92,7 +92,7 @@ dissect_regack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-regreq.c b/plugins/docsis/packet-regreq.c
index b4bceb2b74..57a06dd0b6 100644
--- a/plugins/docsis/packet-regreq.c
+++ b/plugins/docsis/packet-regreq.c
@@ -87,7 +87,7 @@ dissect_regreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-regrsp.c b/plugins/docsis/packet-regrsp.c
index 36c238b938..94471cee9f 100644
--- a/plugins/docsis/packet-regrsp.c
+++ b/plugins/docsis/packet-regrsp.c
@@ -90,7 +90,7 @@ dissect_regrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-rngreq.c b/plugins/docsis/packet-rngreq.c
index c0dfe477ca..cb056ffcdf 100644
--- a/plugins/docsis/packet-rngreq.c
+++ b/plugins/docsis/packet-rngreq.c
@@ -90,7 +90,7 @@ dissect_rngreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-rngrsp.c b/plugins/docsis/packet-rngrsp.c
index 0c5551343f..d2687f9707 100644
--- a/plugins/docsis/packet-rngrsp.c
+++ b/plugins/docsis/packet-rngrsp.c
@@ -197,7 +197,7 @@ dissect_rngrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-tlv.c b/plugins/docsis/packet-tlv.c
index 2f2836af16..ef1a356247 100644
--- a/plugins/docsis/packet-tlv.c
+++ b/plugins/docsis/packet-tlv.c
@@ -2087,7 +2087,7 @@ dissect_tlv (tvbuff_t * tvb, packet_info * pinfo _U_, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-type29ucd.c b/plugins/docsis/packet-type29ucd.c
index 3295c86a55..041e32fe87 100644
--- a/plugins/docsis/packet-type29ucd.c
+++ b/plugins/docsis/packet-type29ucd.c
@@ -822,7 +822,7 @@ dissect_type29ucd (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-uccreq.c b/plugins/docsis/packet-uccreq.c
index d9dafd30e9..07fee12ffd 100644
--- a/plugins/docsis/packet-uccreq.c
+++ b/plugins/docsis/packet-uccreq.c
@@ -87,7 +87,7 @@ dissect_uccreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-uccrsp.c b/plugins/docsis/packet-uccrsp.c
index 5efb27c2a5..da7bd6fbe9 100644
--- a/plugins/docsis/packet-uccrsp.c
+++ b/plugins/docsis/packet-uccrsp.c
@@ -80,7 +80,7 @@ dissect_uccrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-ucd.c b/plugins/docsis/packet-ucd.c
index d0f27bde68..83be89b588 100644
--- a/plugins/docsis/packet-ucd.c
+++ b/plugins/docsis/packet-ucd.c
@@ -648,7 +648,7 @@ static void
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/docsis/packet-vendor.c b/plugins/docsis/packet-vendor.c
index 7c89fde427..00b157ece3 100644
--- a/plugins/docsis/packet-vendor.c
+++ b/plugins/docsis/packet-vendor.c
@@ -224,7 +224,7 @@ dissect_cisco (tvbuff_t * tvb, proto_tree * tree, gint vsif_len)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/giop/packet-coseventcomm.c b/plugins/giop/packet-coseventcomm.c
index 1e66c82ade..5c877eefe0 100644
--- a/plugins/giop/packet-coseventcomm.c
+++ b/plugins/giop/packet-coseventcomm.c
@@ -795,7 +795,7 @@ static gboolean dissect_coseventcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tr
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
void proto_register_giop_coseventcomm(void) {
diff --git a/plugins/h223/packet-h223.c b/plugins/h223/packet-h223.c
index 9b6a532769..db646cc557 100644
--- a/plugins/h223/packet-h223.c
+++ b/plugins/h223/packet-h223.c
@@ -49,10 +49,10 @@
#define PROTO_TAG_H223 "H223"
-/* Ethereal ID of the H.223 protocol */
+/* Wireshark ID of the H.223 protocol */
static int proto_h223 = -1;
-/* The following hf_* variables are used to hold the ethereal IDs of
+/* The following hf_* variables are used to hold the Wireshark IDs of
* our header fields; they are filled out when we call
* proto_register_field_array() in proto_register_h223()
*/
diff --git a/plugins/h223/packet-srp.c b/plugins/h223/packet-srp.c
index f79d5692f7..1530b8541c 100644
--- a/plugins/h223/packet-srp.c
+++ b/plugins/h223/packet-srp.c
@@ -38,11 +38,11 @@
#include "packet-srp.h"
-/* Ethereal ID of the protocols */
+/* Wireshark ID of the protocols */
static int proto_srp = -1;
static int proto_ccsrl = -1;
-/* The following hf_* variables are used to hold the ethereal IDs of
+/* The following hf_* variables are used to hold the Wireshark IDs of
* our header fields; they are filled out when we call
* proto_register_field_array() in proto_register_srp()
*/
diff --git a/plugins/irda/packet-irda.c b/plugins/irda/packet-irda.c
index def83e109a..4a7c8fbf3c 100644
--- a/plugins/irda/packet-irda.c
+++ b/plugins/irda/packet-irda.c
@@ -1940,7 +1940,7 @@ static void init_irda(void)
/*
- * Register the protocol with Ethereal
+ * Register the protocol with Wireshark
* This format is required because a script is used to build the C function
* that calls all the protocol registrations.
*/
diff --git a/plugins/lua/elua.c b/plugins/lua/elua.c
index 6564688237..da5ab57d56 100644
--- a/plugins/lua/elua.c
+++ b/plugins/lua/elua.c
@@ -1,7 +1,7 @@
/*
* packet-lua.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua.h b/plugins/lua/elua.h
index 03d4b588c9..287c8e2769 100644
--- a/plugins/lua/elua.h
+++ b/plugins/lua/elua.h
@@ -1,7 +1,7 @@
/*
* packet-lua.h
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua_dumper.c b/plugins/lua/elua_dumper.c
index 202bcacf09..2d0e75f9ce 100644
--- a/plugins/lua/elua_dumper.c
+++ b/plugins/lua/elua_dumper.c
@@ -1,7 +1,7 @@
/*
* lua_dumper.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua_field.c b/plugins/lua/elua_field.c
index 37d3fed17b..d65df90f73 100644
--- a/plugins/lua/elua_field.c
+++ b/plugins/lua/elua_field.c
@@ -1,7 +1,7 @@
/*
* elua_field.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua_gui.c b/plugins/lua/elua_gui.c
index fd9b384137..79c03e9274 100644
--- a/plugins/lua/elua_gui.c
+++ b/plugins/lua/elua_gui.c
@@ -499,7 +499,7 @@ ELUA_FUNCTION elua_retap_packets(lua_State* L) {
if ( ops->retap_packets ) {
ops->retap_packets();
} else {
- ELUA_ERROR(elua_retap_packets, "does not work on tethereal");
+ ELUA_ERROR(elua_retap_packets, "does not work on tWireshark");
}
return 0;
diff --git a/plugins/lua/elua_pinfo.c b/plugins/lua/elua_pinfo.c
index 37b2e85688..f569d1782e 100644
--- a/plugins/lua/elua_pinfo.c
+++ b/plugins/lua/elua_pinfo.c
@@ -1,7 +1,7 @@
/*
* lua_pinfo.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua_plugin.c b/plugins/lua/elua_plugin.c
index 6f646c23a5..9cddf1062a 100644
--- a/plugins/lua/elua_plugin.c
+++ b/plugins/lua/elua_plugin.c
@@ -1,7 +1,7 @@
/*
* plugin.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua_proto.c b/plugins/lua/elua_proto.c
index d6d3a8decf..3144f3101e 100644
--- a/plugins/lua/elua_proto.c
+++ b/plugins/lua/elua_proto.c
@@ -1,7 +1,7 @@
/*
* lua_proto.c
*
- * Ethereal's interface to the Lua Programming Language
+ * wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua_tap.c b/plugins/lua/elua_tap.c
index 3ed4eb5fd8..451ec6867e 100644
--- a/plugins/lua/elua_tap.c
+++ b/plugins/lua/elua_tap.c
@@ -1,7 +1,7 @@
/*
* lua_tap.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
@@ -272,7 +272,7 @@ static int Tap_newindex(lua_State* L) {
function tap.packet(pinfo,tvb,userdata) ... end
*/
/* ELUA_ATTRIBUTE Tap_draw WO A function that will be called once every few seconds to redraw the gui objects
- in tethereal this funtion is called oly at the very end of the capture file.
+ in twireshark this funtion is called oly at the very end of the capture file.
function tap.draw(userdata) ... end
*/
diff --git a/plugins/lua/elua_tree.c b/plugins/lua/elua_tree.c
index e2d8e23074..9eb1866929 100644
--- a/plugins/lua/elua_tree.c
+++ b/plugins/lua/elua_tree.c
@@ -1,7 +1,7 @@
/*
* elua_tree.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
diff --git a/plugins/lua/elua_tvb.c b/plugins/lua/elua_tvb.c
index 1cbb61badb..6a48d107a2 100644
--- a/plugins/lua/elua_tvb.c
+++ b/plugins/lua/elua_tvb.c
@@ -1,7 +1,7 @@
/*
* lua_tvb.c
*
- * Ethereal's interface to the Lua Programming Language
+ * Wireshark's interface to the Lua Programming Language
*
* (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
@@ -287,7 +287,7 @@ int ByteArray_register(lua_State* L) {
*
* a Tvb represents a tvbuff_t in Lua.
* a TvbRange represents a range in a tvb (tvb,offset,lenght) it's main purpose is to do bounds checking,
- * it helps too simplifing argument passing to Tree. In ethereal terms this is worthless nothing
+ * it helps too simplifing argument passing to Tree. In wireshark terms this is worthless nothing
* not already done by the TVB itself. In lua's terms is necessary to avoid abusing TRY{}CATCH(){}
* via preemptive bounds checking.
*
diff --git a/plugins/mate/mate_setup.c b/plugins/mate/mate_setup.c
index 95ccd8e26d..f0fa63145c 100644
--- a/plugins/mate/mate_setup.c
+++ b/plugins/mate/mate_setup.c
@@ -919,7 +919,7 @@ extern mate_config* mate_make_config(const gchar* filename, int mate_hfid) {
analyze_config();
} else {
report_failure("MATE failed to configue!\n"
- "It is recommended that you fix your config and restart ethereal.\n"
+ "It is recommended that you fix your config and restart wireshark.\n"
"The reported error is:\n%s\n",matecfg->config_error->str);
/* if (matecfg) destroy_mate_config(matecfg,FALSE); */
diff --git a/plugins/mate/packet-mate.c b/plugins/mate/packet-mate.c
index 3de641a568..d4132cace1 100644
--- a/plugins/mate/packet-mate.c
+++ b/plugins/mate/packet-mate.c
@@ -327,7 +327,7 @@ proto_reg_handoff_mate(void)
if (current_mate_config_filename) {
report_failure("Mate cannot reconfigure itself.\n"
- "for changes to be applied you have to restart ethereal\n");
+ "for changes to be applied you have to restart wireshark\n");
return;
}
diff --git a/plugins/rlm/packet-rlm.c b/plugins/rlm/packet-rlm.c
index cbe18d69e4..ce98977efa 100644
--- a/plugins/rlm/packet-rlm.c
+++ b/plugins/rlm/packet-rlm.c
@@ -166,7 +166,7 @@ dissect_rlm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
}
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
diff --git a/plugins/v5ua/packet-v5ua.c b/plugins/v5ua/packet-v5ua.c
index 45e3084312..cd26d16aa5 100644
--- a/plugins/v5ua/packet-v5ua.c
+++ b/plugins/v5ua/packet-v5ua.c
@@ -1965,7 +1965,7 @@ dissect_v5ua(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration. */
diff --git a/plugins/asn1/packet-asn1.c b/plugins/asn1/packet-asn1.c
index 762794ae10..2155495453 100644
--- a/plugins/asn1/packet-asn1.c
+++ b/plugins/asn1/packet-asn1.c
@@ -29,7 +29,7 @@
/**************************************************************************
* This plugin will dissect BER encoded ASN.1 messages in UDP packets or in
* a TCP stream. It relies on ethereal to do defragmentation and re-assembly
* to construct complete messages.
*
* To produce packet display with good annotations it needs to know about
@@ -47,7 +47,7 @@
* - cd /tmp
* - snacc -u /usr/include/snacc/asn1/asn-useful.asn1 -T tbl.tt /usr/include/snacc/asn1/tbl.asn1
* - od -Ax -tx1 tbl.tt | text2pcap -T 801,801 - tbl.tt.pcap
- * - ethereal tbl.tt.pcap
+ * - wireshark tbl.tt.pcap
* GUI: Edit->Preferences->Protocols->ASN1
* type table file: /tmp/tbl.tt
* PDU name: TBL
@@ -158,7 +158,7 @@ static gboolean asn1_full = FALSE; /* show full names */
static guint type_recursion_level = 1; /* eliminate 1 level of references */
static char *asn1_logfile = NULL;
-#define ASN1LOGFILE "ethereal.log"
+#define ASN1LOGFILE "wireshark.log"
/* PDU counter, for correlation between GUI display and log file in debug mode */
static int pcount = 0;
@@ -309,8 +309,8 @@ static const char *tbl_types_asn1[] = {
/* 19 */ "INVALID entry",
};
-/* conversion from snacc type to appropriate ethereal type */
-static guint tbl_types_ethereal[] = {
+/* conversion from snacc type to appropriate wireshark type */
+static guint tbl_types_wireshark[] = {
/* 0 */ FT_BOOLEAN, /* TBL_BOOLEAN */
/* 1 */ FT_UINT32, /* TBL_INTEGER */
/* 2 */ FT_UINT32, /* TBL_BITSTRING */
@@ -335,7 +335,7 @@ static guint tbl_types_ethereal[] = {
/* 19 */ FT_NONE, /* TBL_INVALID */
};
-static const char *tbl_types_ethereal_txt[] = {
+static const char *tbl_types_wireshark_txt[] = {
/* 0 */ "FT_BOOLEAN", /* TBL_BOOLEAN */
/* 1 */ "FT_UINT32", /* TBL_INTEGER */
/* 2 */ "FT_UINT32", /* TBL_BITSTRING */
@@ -373,9 +373,9 @@ struct _PDUinfo {
gint typenum;
gint basetype; /* parent type */
gint mytype; /* original type number, typenum may have gone through a reference */
- gint value_id; /* ethereal field id for the value in this PDU */
- gint type_id; /* ethereal field id for the type of this PDU */
- hf_register_info value_hf; /* ethereal field info for this value */
+ gint value_id; /* wireshark field id for the value in this PDU */
+ gint type_id; /* wireshark field id for the type of this PDU */
+ hf_register_info value_hf; /* wireshark field info for this value */
};
@@ -1020,7 +1020,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
asn1_close(&asn1, &offset); /* mark where we are now */
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected: just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset, textfmt_d, boffset,
@@ -1037,7 +1037,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1059,7 +1059,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
ename = getPDUenum(&props, boffset, cls, tag, value);
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1076,7 +1076,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1097,7 +1097,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
asn1_close(&asn1, &offset); /* mark where we are now */
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_BOOLEAN) )
+ (tbl_types_wireshark[props.type] != FT_BOOLEAN) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1114,7 +1114,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_BOOLEAN) )
+ (tbl_types_wireshark[props.type] != FT_BOOLEAN) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1146,7 +1146,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
ename = showoctets(octets, len, (tag == ASN1_OTS) ? 4 : 0 );
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_STRINGZ) )
+ (tbl_types_wireshark[props.type] != FT_STRINGZ) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1163,7 +1163,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_STRINGZ) )
+ (tbl_types_wireshark[props.type] != FT_STRINGZ) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1187,7 +1187,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
ename = showbitnames(bits, (con*8)-unused, &props, offset);
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1207,7 +1207,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1300,7 +1300,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
ename = showoid(oid, con);
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_BYTES) )
+ (tbl_types_wireshark[props.type] != FT_BYTES) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset, offset - boffset, textfmt_s,
boffset, clsstr, constr, tagstr, tname, name,
@@ -1315,7 +1315,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_BYTES) )
+ (tbl_types_wireshark[props.type] != FT_BYTES) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset,
offset - boffset,
@@ -1382,7 +1382,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
asn1_close(&asn1, &offset); /* mark where we are now */
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1399,7 +1399,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1423,7 +1423,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
ename = getPDUenum(&props, boffset, cls, tag, value);
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1440,7 +1440,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1464,7 +1464,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
ename = showbitnames(bits, (con*8)-unused, &props, offset);
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1485,7 +1485,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_UINT32) )
+ (tbl_types_wireshark[props.type] != FT_UINT32) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset, offset - boffset,
"(%s)%s: %s:%s", tname, name,
@@ -1509,7 +1509,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
asn1_close(&asn1, &offset); /* mark where we are now */
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_BOOLEAN) )
+ (tbl_types_wireshark[props.type] != FT_BOOLEAN) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1528,7 +1528,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_BOOLEAN) )
+ (tbl_types_wireshark[props.type] != FT_BOOLEAN) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1569,7 +1569,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
ename = showoctets(octets, len, 2); /* convert octets to printable */
if (asn1_debug) {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_STRINGZ) )
+ (tbl_types_wireshark[props.type] != FT_STRINGZ) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb,
boffset, offset - boffset,
@@ -1586,7 +1586,7 @@ decode_asn1_sequence(tvbuff_t *tvb, guint offset, guint tlen, proto_tree *pt, in
}
} else {
if ( (props.value_id == -1) ||
- (tbl_types_ethereal[props.type] != FT_STRINGZ) )
+ (tbl_types_wireshark[props.type] != FT_STRINGZ) )
/* unknown or unexpected, just text */
proto_tree_add_text(pt, tvb, boffset, offset - boffset,
"(%s)%s: %s", tname, name, ename);
@@ -2934,7 +2934,7 @@ tbl_typeref(guint n, GNode *pdu, GNode *tree, guint fullindex)
/* names do not have a fullname */
if (asn1_verbose) g_message("%*s*collection T %s", n*2, empty, p->name);
/* read the enumeration [save min-max somewhere ?] */
- p->value_hf.hfinfo.type = tbl_types_ethereal[p->type]; /* XXX change field type... */
+ p->value_hf.hfinfo.type = tbl_types_wireshark[p->type]; /* XXX change field type... */
proto_register_field_array(proto_asn1, &(p->value_hf) , 1);
@@ -2944,7 +2944,7 @@ tbl_typeref(guint n, GNode *pdu, GNode *tree, guint fullindex)
g_message("regtype1: %3d %3d [%3d] F%2.2x (%s)%s %s %s -> id=%d",
p->mytype, p->typenum, p->basetype, p->flags, p->typename,
p->name, p->fullname,
- tbl_types_ethereal_txt[p->type], p->value_id);
+ tbl_types_wireshark_txt[p->type], p->value_id);
p1 = p;
nvals = 0;
while((q = g_node_next_sibling(q))) {
@@ -2977,7 +2977,7 @@ tbl_typeref(guint n, GNode *pdu, GNode *tree, guint fullindex)
case TBL_CHOICE:
if (p->value_id == -1) { /* not yet registered ..... */
- p->value_hf.hfinfo.type = tbl_types_ethereal[p->type];
+ p->value_hf.hfinfo.type = tbl_types_wireshark[p->type];
proto_register_field_array(proto_asn1, &(p->value_hf) , 1);
save_reference(p);
@@ -2986,14 +2986,14 @@ tbl_typeref(guint n, GNode *pdu, GNode *tree, guint fullindex)
g_message("regtype2: %3d %3d [%3d] F%2.2x (%s)%s %s %s -> id=%d",
p->mytype, p->typenum, p->basetype, p->flags, p->typename,
p->name, p->fullname,
- tbl_types_ethereal_txt[p->type], p->value_id);
+ tbl_types_wireshark_txt[p->type], p->value_id);
}
tbl_type(n, pdu, q, fullindex);
break;
default:
if (p->value_id == -1) { /* not yet registered ..... */
- p->value_hf.hfinfo.type = tbl_types_ethereal[p->type];
+ p->value_hf.hfinfo.type = tbl_types_wireshark[p->type];
proto_register_field_array(proto_asn1, &(p->value_hf) , 1);
save_reference(p);
@@ -3002,7 +3002,7 @@ tbl_typeref(guint n, GNode *pdu, GNode *tree, guint fullindex)
g_message("regtype3: %3d %3d [%3d] F%2.2x (%s)%s %s %s -> id=%d",
p->mytype, p->typenum, p->basetype, p->flags, p->typename,
p->name, p->fullname,
- tbl_types_ethereal_txt[p->type], p->value_id);
+ tbl_types_wireshark_txt[p->type], p->value_id);
}
tbl_type(n, pdu, g_node_next_sibling(q), fullindex);
}
@@ -3075,7 +3075,7 @@ tbl_type(guint n, GNode *pdu, GNode *list, guint fullindex) /* indent, pdu, sour
p->value_hf.p_id = &(p->value_id);
p->value_hf.hfinfo.name = p->fullname;
p->value_hf.hfinfo.abbrev = p->fullname;
- p->value_hf.hfinfo.type = tbl_types_ethereal[p->type];
+ p->value_hf.hfinfo.type = tbl_types_wireshark[p->type];
p->value_hf.hfinfo.display = BASE_DEC;
p->value_hf.hfinfo.blurb = p->fullname;
/* all the other fields are already 0 ! */
@@ -3090,7 +3090,7 @@ tbl_type(guint n, GNode *pdu, GNode *list, guint fullindex) /* indent, pdu, sour
g_message("register: %3d %3d [%3d] F%2.2x (%s)%s %s %s -> id=%d",
p->mytype, p->typenum, p->basetype, p->flags,
p->typename, p->name, p->fullname,
- tbl_types_ethereal_txt[p->type], p->value_id);
+ tbl_types_wireshark_txt[p->type], p->value_id);
}
q = g_node_first_child(list);
@@ -3247,7 +3247,7 @@ tbl_type(guint n, GNode *pdu, GNode *list, guint fullindex) /* indent, pdu, sour
g_message("regist-2: %3d %3d [%3d] F%2.2x (%s)%s %s %s -> id=%d",
p->mytype, p->typenum, p->basetype, p->flags, p->typename,
p->name, p->fullname,
- tbl_types_ethereal_txt[p->type], p->value_id);
+ tbl_types_wireshark_txt[p->type], p->value_id);
}
list = g_node_next_sibling(list);
}
@@ -3377,7 +3377,7 @@ build_pdu_tree(const char *pduname)
info->value_hf.p_id = &(info->value_id);
info->value_hf.hfinfo.name = info->fullname;
info->value_hf.hfinfo.abbrev = info->fullname;
- info->value_hf.hfinfo.type = tbl_types_ethereal[info->type];
+ info->value_hf.hfinfo.type = tbl_types_wireshark[info->type];
info->value_hf.hfinfo.display = BASE_DEC;
info->value_hf.hfinfo.blurb = info->fullname;
@@ -3425,7 +3425,7 @@ build_pdu_tree(const char *pduname)
info->value_hf.p_id = &(info->value_id);
info->value_hf.hfinfo.name = info->fullname;
info->value_hf.hfinfo.abbrev = info->fullname;
- info->value_hf.hfinfo.type = tbl_types_ethereal[info->type];
+ info->value_hf.hfinfo.type = tbl_types_wireshark[info->type];
info->value_hf.hfinfo.display = BASE_DEC;
info->value_hf.hfinfo.blurb = info->fullname;
@@ -3506,7 +3506,7 @@ build_pdu_tree(const char *pduname)
#ifdef DISSECTOR_WITH_GUI
-/* This cannot work in tethereal.... don't include for now */
+/* This cannot work in twireshark.... don't include for now */
#if GTK_MAJOR_VERSION >= 2
#define SHOWPDU /* this needs GTK2 */
#endif
@@ -29,7 +29,7 @@
/**************************************************************************
* This plugin will dissect BER encoded ASN.1 messages in UDP packets or in
- * a TCP stream. It relies on ethereal to do defragmentation and re-assembly
+ * a TCP stream. It relies on wireshark to do defragmentation and re-assembly
* to construct complete messages.
*